@@ -221,6 +221,7 @@ class LoadMaster(HttpClient):
                             for subvs_api in subvs_api_entries:
                                 if subvs_api["VSIndex"] == subvs.index:
                                     subvs.subvs_data = subvs_api
+                                    subvs.subvs_data['parentvs'] = vs_index
 
                             virt_serv.subvs_entries.append(subvs)
         virt_serv.populate_default_attributes(service)
@@ -487,6 +488,17 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         else:
             return {"vs": self.index}
 
+    def _subvs_to_dict(self):
+        return {
+            "vs": self.subvs_data['parentvs'],
+            "rs": "!{}".format(self.subvs_data['RsIndex']),
+            "name": self.subvs_data['Name'],
+            "forward": self.subvs_data['Forward'],
+            "weight": self.subvs_data['Weight'],
+            "limit": self.subvs_data['Limit'],
+            "critical": self.subvs_data['Critical'],
+        }
+
     @property
     def access_info(self):
         if self.index is None:
@@ -520,14 +532,14 @@ class VirtualService(HttpClient, KempBaseObjectModel):
                 created_subvs_id = [x for x in new_subvs_entries if x not in s]
                 newly_created_vs_params = {"vs": created_subvs_id}
                 self.subvs_data = subvs_data[created_subvs_id[0]]
+                self.subvs_data['parentvs'] = self.vs
                 response = self._get("/showvs", newly_created_vs_params)
-                #data = get_data(response)
-                #subvs = VirtualService(self.access_info, created_subvs_id[0])
-                #subvs.populate_default_attributes(data)
-                #self.subvs_entries.append(subvs)
             else:
                 response = self._get("/addvs", self.to_api_dict())
         else:
+            if self._is_sub_vs:
+                # Update the underlying "Rs" part of the subvs as well
+                self._get("/modrs", self._subvs_to_dict())
             response = self._get("/modvs", self.to_api_dict())
 
         if is_successful(response):
@@ -560,7 +572,7 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         self.idletime = service.get('Idletime', None)
 
     def create_sub_virtual_service(self):
-        """Create a virtual service marked as subvs
+        """VirtualService factory with pre-configured LoadMaster connection
 
         When creating a virtual service that is a sub virtual service you must
         pass the parent index to the constructor and mark the is_sub_vs flag
@@ -657,13 +669,19 @@ class RealServer(HttpClient, KempBaseObjectModel):
 
     def _get_base_parameters(self):
         """Returns the bare minimum VS parameters. IP, port and protocol"""
-        return {
-            "vs": self.vs,
-            "port": self.port,
-            "prot": self.prot,
-            "rs": self.rs,
-            "rsport": self.rsport,
-        }
+        if self.rsindex is None:
+            return {
+                "vs": self.vs,
+                "port": self.port,
+                "prot": self.prot,
+                "rs": self.rs,
+                "rsport": self.rsport,
+            }
+        else:
+            return {
+                "vs": self.vsindex,
+                "rs": "!{}".format(self.rsindex),
+            }
 
     def save(self, update=False):
         if not update:
